==> treuchtlingen-foxde-config_1.0.22.orig.tar.gz: treuchtlingen-foxde-config-1.0.22/kde-configuration/meet/kactivitymanagerd.sql <==
PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE SchemaInfo (key text PRIMARY KEY, value text);
INSERT INTO SchemaInfo VALUES('version','2015.02.09');
CREATE TABLE ResourceEvent (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, start INTEGER, end INTEGER );
CREATE TABLE ResourceScoreCache (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, scoreType INTEGER, cachedScore FLOAT, firstUpdate INTEGER, lastUpdate INTEGER, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
CREATE TABLE ResourceLink (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:firefox-esr.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:microsoft-edge.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:teams.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:webex.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:Zoom.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-jitsi.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-nextcloud.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-poweroff.desktop');
CREATE TABLE ResourceInfo (targettedResource TEXT, title TEXT, mimetype TEXT, autoTitle INTEGER, autoMimetype INTEGER, PRIMARY KEY(targettedResource));
COMMIT;

==> treuchtlingen-foxde-config_1.0.24.orig.tar.gz: treuchtlingen-foxde-config-1.0.24/kde-configuration/meet/kactivitymanagerd.sql <==
PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE SchemaInfo (key text PRIMARY KEY, value text);
INSERT INTO SchemaInfo VALUES('version','2015.02.09');
CREATE TABLE ResourceEvent (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, start INTEGER, end INTEGER );
CREATE TABLE ResourceScoreCache (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, scoreType INTEGER, cachedScore FLOAT, firstUpdate INTEGER, lastUpdate INTEGER, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
CREATE TABLE ResourceLink (usedActivity TEXT, initiatingAgent TEXT, targettedResource TEXT, PRIMARY KEY(usedActivity, initiatingAgent, targettedResource));
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:firefox-esr.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:microsoft-edge.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:x2goclient.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-jitsi.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-nextcloud.desktop');
INSERT INTO ResourceLink VALUES(':global','org.kde.plasma.favorites.applications','applications:treuchtlingen-poweroff.desktop');
CREATE TABLE ResourceInfo (targettedResource TEXT, title TEXT, mimetype TEXT, autoTitle INTEGER, autoMimetype INTEGER, PRIMARY KEY(targettedResource));
COMMIT;
